# Flask EasyLog

API for management log by Flask

#### GET

### /api/logs

#### configuration of endpoint

Response content-type: application/json

#### GET

### /api/log/{endpoint}

#### configuration of specific endpoint

Response content-type: application/json

#### Parameters

endpoint |

#### DELETE

### /api/log/{endpoint}

#### delete specific configuration of endpoint

Response content-type: application/json

#### Parameters

endpoint |

#### PUT

### /api/log/{endpoint}

#### add or change specific configuration of endpoint

Response content-type: application/json

#### Parameters

endpoint |
body | { "endpoint":"hello", "level":"INFO" }